@@ -4,7 +4,7 @@
 -- basic functionality successfully.
 --
 -- Copyright (C) 2011 Xiaona Han
--- Copyright (C) 2011,2012,2014,2016 Olly Betts
+-- Copyright (C) 2011,2012,2014,2016,2017 Olly Betts
 --
 -- This program is free software; you can redistribute it and/or
 -- modify it under the terms of the GNU General Public License as
@@ -181,6 +181,13 @@ function run_tests()
   -- Regression test for bug#192 - fixed in 1.0.3.
   enq:set_cutoff(100)
 
+  -- Check DateRangeProcessor works
+  qp = xapian.QueryParser()
+  rpdate = xapian.DateRangeProcessor(1, xapian.RP_DATE_PREFER_MDY, 1960)
+  qp:add_rangeprocessor(rpdate)
+  query = qp:parse_query("12/03/99..12/04/01")
+  expect(tostring(query), "Query(VALUE_RANGE 1 19991203 20011204)")
+
   -- Check DateValueRangeProcessor works
   qp = xapian.QueryParser()
   vrpdate = xapian.DateValueRangeProcessor(1, true, 1960)
