@@ -869,7 +869,7 @@ def test_queryparser_custom_vrp():
     query = queryparser.parse_query('5..8')
 
     expect(str(query),
-           'Query(0 * VALUE_RANGE 7 A5 B8)')
+           'Query(VALUE_RANGE 7 A5 B8)')
 
 def test_queryparser_custom_vrp_deallocation():
     """Test that QueryParser doesn't delete ValueRangeProcessors too soon.
@@ -892,7 +892,7 @@ def test_queryparser_custom_vrp_deallocation():
     query = queryparser.parse_query('5..8')
 
     expect(str(query),
-           'Query(0 * VALUE_RANGE 7 A5 B8)')
+           'Query(VALUE_RANGE 7 A5 B8)')
 
 def test_queryparser_custom_rp():
     """Test QueryParser with a custom (in python) RangeProcessor.
@@ -914,7 +914,7 @@ def test_queryparser_custom_rp():
     query = queryparser.parse_query('5..8')
 
     expect(str(query),
-           'Query(0 * VALUE_RANGE 7 A5 B8)')
+           'Query(VALUE_RANGE 7 A5 B8)')
 
 def test_queryparser_custom_rp_deallocation():
     """Test that QueryParser doesn't delete RangeProcessors too soon.
@@ -939,7 +939,7 @@ def test_queryparser_custom_rp_deallocation():
     query = queryparser.parse_query('5..8')
 
     expect(str(query),
-           'Query(0 * VALUE_RANGE 7 A5 B8)')
+           'Query(VALUE_RANGE 7 A5 B8)')
 
 def test_scale_weight():
     """Test query OP_SCALE_WEIGHT feature.
