@@ -1,7 +1,7 @@
 # Simple test to ensure that we can load the xapian module and exercise basic
 # functionality successfully.
 #
-# Copyright (C) 2004,2005,2006,2007,2008,2010,2011,2012,2014,2015,2016 Olly Betts
+# Copyright (C) 2004,2005,2006,2007,2008,2010,2011,2012,2014,2015,2016,2017 Olly Betts
 # Copyright (C) 2007 Lemur Consulting Ltd
 #
 # This program is free software; you can redistribute it and/or
@@ -367,7 +367,7 @@ def test_all():
     vrpdate = xapian.DateValueRangeProcessor(1, 1, 1960)
     qp.add_valuerangeprocessor(vrpdate)
     query = qp.parse_query('12/03/99..12/04/01')
-    expect(str(query), 'Query(0 * VALUE_RANGE 1 19991203 20011204)')
+    expect(str(query), 'Query(VALUE_RANGE 1 19991203 20011204)')
 
     # Regression test for bug#193, fixed in 1.0.3.
     context("running regression test for bug#193")
@@ -389,6 +389,10 @@ def test_all():
 
     qp.add_prefix('spam', testfieldprocessor())
     qp.add_boolean_prefix('boolspam', testfieldprocessor())
+    qp.add_boolean_prefix('boolspam2', testfieldprocessor(), False) # Old-style
+    qp.add_boolean_prefix('boolspam3', testfieldprocessor(), '')
+    qp.add_boolean_prefix('boolspam4', testfieldprocessor(), 'group')
+    qp.add_boolean_prefix('boolspam5', testfieldprocessor(), None)
     query = qp.parse_query('spam:ignored')
     expect(str(query), 'Query(spam)')
 
@@ -405,6 +409,17 @@ def test_all():
     oqparser = xapian.QueryParser()
     oquery = oqparser.parse_query("I like tea")
 
+    # Regression test for bug fixed in 1.4.4:
+    # https://bugs.debian.org/849722
+    oqparser.add_boolean_prefix('tag', 'K', '')
+    # Make sure other cases also work:
+    oqparser.add_boolean_prefix('zag', 'XR', False) # Old-style
+    oqparser.add_boolean_prefix('rag', 'XR', None)
+    oqparser.add_boolean_prefix('nag', 'XB', '')
+    oqparser.add_boolean_prefix('bag', 'XB', 'blergh')
+    oqparser.add_boolean_prefix('gag', 'XB', u'blergh')
+    oqparser.add_boolean_prefix('jag', 'XB', b'blergh')
+
     # Regression test for bug#192 - fixed in 1.0.3.
     enq.set_cutoff(100)
 
