@@ -428,7 +428,6 @@ def test_all():
     oqparser.add_boolean_prefix('rag', 'XR', None)
     oqparser.add_boolean_prefix('nag', 'XB', '')
     oqparser.add_boolean_prefix('bag', 'XB', 'blergh')
-    oqparser.add_boolean_prefix('gag', 'XB', u'blergh')
     oqparser.add_boolean_prefix('jag', 'XB', b'blergh')
 
     # Regression test for bug#192 - fixed in 1.0.3.
@@ -471,6 +470,26 @@ def test_userstem():
     parser.set_stemming_strategy(xapian.QueryParser.STEM_ALL)
     expect_query(parser.parse_query(b'color television'), '(clr@1 OR tlvsn@2)')
 
+def test_internal_enums_not_wrapped():
+    leaf_constants = [c for c in dir(xapian.Query) if c.startswith('LEAF_')]
+    expect(leaf_constants, [])
+
+def test_internals_not_wrapped():
+    internals = []
+    for c in dir(xapian):
+        # Skip Python stuff like __file__ and __version__.
+        if c.startswith('__'): continue
+        if c.endswith('_'): internals.append(c)
+        # Skip non-classes
+        if not c[0].isupper(): continue
+        cls = eval('xapian.' + c)
+        if type(cls) != type(object): continue
+        for m in dir(cls):
+            if m.startswith('__'): continue
+            if m.endswith('_'): internals.append(c + '.' + m)
+
+    expect(internals, [])
+
 def test_zz9_check_leaks():
     import gc
     gc.collect()
